G.test(x, p = rep(1/length(x), length(x)))x is matrix, it must be constructed like this:
- 2 columns giving number of successes (left) and fails (right)
- 1 row per population.
The function works as chisq.test :
- if x is a vector and theoretical proportions are not given, equality of counts is tested
- if x is a vector and theoretical proportions are given, equality of counts to theoretical counts (given by theoretical proportions) is tested
- if x is a matrix with two coloums, equality of proportion of successes between populations is tested.
- if x is a matrix with more than two coloums, independence of rows and columns is tested.
Since a G-test is an approximate test, an exact test is preferable when the number of individuals is small (200 is a reasonable minimum). See multinomial.test in that case with a vector, fisher.test with a matrix.chisq.test, multinomial.test, fisher.test G.multcomp, G.theo.multcomp, pairwise.G.testcounts <- c(49,30,63,59)
G.test(counts)Run the code above in your browser using DataLab