MVA.pairplot(x, xax = 1, yax = 2, pairs = NULL, scaling = 2, space = 1, fac = NULL,
xlab = NULL, ylab = NULL, main = NULL, ident = TRUE, labels = NULL, cex = 0.7, col = 1,
lwd = 1, main.pos = c("bottomleft", "topleft", "bottomright", "topright"),
main.cex = 1.3, legend = FALSE, legend.pos = c("topleft", "topright", "bottomleft",
"bottomright"), legend.title = NULL, legend.lab = NULL, drawextaxes = TRUE,
drawintaxes = TRUE, xlim = NULL, ylim = NULL)NULL, only two-dimensional graphs can be drawn.MVvegan package. See Details of MVA.scoreplot.MVA.scoreplot). space is the number of the space to be plotted.NULL (default), automatic labels are used depending on the multivariate analysis.NULL (default), automatic labels are used depending on the multivariate analysis.NULL (default), labels correspond to row names of the data used in the multivariate analysis.fac is not NULL, can be a vector of length one or a vector giving one value per group. Otherwise a vector of any length can be defined, which is recycled if necessary.fac is not NULL, can be a vector of length one or a vector giving one value per group. Otherwise a vector of any length can be defined, which is recycled if necessary.fac is not NULL, can be a vector of length one or a vector giving one value per group. Otherwise a vector of any length can be defined, which is recycled if necessary.main is not NULL. Default to "bottomleft".main is not NULL.legend is TRUE. Default to "topleft".legend is TRUE.legend is TRUE. If NULL and fac is defined, levels of fac are used.NULL, limits are computed automatically.NULL, limits are computed automatically.MVA.plot, to which all arguments can be passed.
All multivariate analyses supported by MVA.scoreplot can be used for a paired plot.require(ade4)
data(macaca)
PCIA <- procuste(macaca$xy1,macaca$xy2)
MVA.plot(PCIA,"pairs")Run the code above in your browser using DataLab