MVA.plot(x, type = c("scores", "loadings", "correlations", "biplot", "pairs",
"trajectories"), ...)MVA.scoreplot, MVA.loadplot, MVA.corplot, MVA.biplot, MVA.pairplot or MVA.trajplot. These functions should not be used directly (everything can be done with the general MVA.plot) but for convenience, arguments and analyses supported are detailed in separate help pages.
Warning: the use of attach before running a multivariate analysis can prevent MVA.plot to get the values it needs, and make it fail.