Learn R Programming

RVAideMemoire (version 0.9-5)

MVA.synt: Synthesis quality of multivariate analyses

Description

Gives a simple estimator of the quality of the (descriptive) synthesis performed by a wide range of multivariate analyses.

Usage

MVA.synt(x, rows = 5)

Arguments

x
a multivariate analysis (see Details).
rows
maximum number of axes to print in the output.

Details

Many multivariate analyses are supported, from various packages. The list will progressively get longer (and additional criteria will be given). - PCA: prcomp, princomp, dudi.pca, rda, pca, pca: % of total variance explained by each axis. - sPCA: spca: % of total variance explained by each axis. - IPCA: ipca: kurtosis of each axis. - sIPCA: sipca: kurtosis of each axis. - PCoA: cmdscale (with eig=TRUE), dudi.pco, wcmdscale (with eig=TRUE), capscale, pco, pcoa: % of total variance explained by each axis. - nMDS: monoMDS, metaMDS, nmds, isoMDS: stress. - LDA: lda, discrimin: % of intergroup variance explained by each axis. - PLS-DA (PLS2 on a dummy-coded factor): plsda: % of intergroup variance explained by each axis. - CPPLS: mvr: % of X and Y variances explained by each axis. - PLSR: mvr, plsR: % of X and Y variances explained by each axis (only Y for the moment with plsR). - PCR: mvr: % of X and Y variances explained by each axis. - CDA: discrimin, discrimin.coa: % of intergroup variance explained by each axis.

Examples

Run this code
data(iris)
PCA <- prcomp(iris[,1:4])
MVA.synt(PCA,"scores")

Run the code above in your browser using DataLab