MVA.trajplot(x, xax = 1, yax = 2, trajects, trajlab = NULL, scaling = 2,
set = c(12, 1, 2), space = 1, xlab = NULL, ylab = NULL, main = NULL,
pch = 16, cex = 1, trajlab.cex = 1, col = 1, lwd = 1, lty = 1,
points = TRUE, allpoints = TRUE, arrows = TRUE, labels = NULL,
main.pos = c("bottomleft", "topleft", "bottomright", "topright"),
main.cex = 1.3, legend = FALSE, legend.pos = c("topleft", "topright",
"bottomleft", "bottomright"), legend.title = NULL, legend.lab = NULL,
legend.cex = 1, drawextaxes = TRUE, drawintaxes = TRUE, xlim = NULL,
ylim = NULL)NULL, only two-dimensional graphs can be drawn.vegan package. See Details of MVA.scoreplot.MVA.scoreplot). 12 (default) for both sets, 1 for rows or X, 2 for columns oMVA.scoreplot). space is the number of the space to be plotted.NULL (default), automatic labels are used depending on the multivariate analysis.NULL (default), automatic labels are used depending on the multivariate analysis.allpoints=TRUE).allpoints=TRUE).fac is not NULL, can be a vector of length one or a vector giving one value per group. Otherwise a vector of any length can be defined, which is recycled if necessary.FALSE, points are replaced with their corresponding label (defined by labels).NULL (default), labels correspond to row names of the data used in the multivariate analysis.main is not NULL. Default to "bottomleft".main is not NULL.legend is TRUE. Default to "topleft".legend is TRUE.legend is TRUE. If NULL and trajlab is defined, values of trajlab are used.legend is TRUE.NULL, limits are computed automatically.NULL, limits are computed automatically.MVA.plot, to which all arguments can be passed.
All multivariate analyses supported by MVA.scoreplot can be used for a paired plot.\require(ade4)
data(olympic)
PCA <- dudi.pca(olympic$tab,scannf=FALSE)
MVA.plot(PCA,"traject",trajects=list(1:10,25:30),col=c(2,3,1),trajlab=c("T1","T2"))Run the code above in your browser using DataLab