ancova.multcomp: Pairwise comparisons after an analysis of covariance
Description
Plot and return mean of the dependent variable for each class of the factor, adjusted for the covariate, and 95% confidence interval of these means. The function deals with lm, glm and glm.nb models.Usage
ancova.multcomp(model)
Arguments
model
lm, glm or glm.nb model.