Re-computes an ordination using given row weights (possibly extracted from a correspondence analysis). The function is intended to be used prior to coinertia when row weights have to be equalized.
ord.rw(ord, CA = NULL, rw = NULL)an ordination to re-compute. Must come from the ade4 package or be supported by to.dudi. In any case the resulting ordination will be in the ade4 format.
an optional vector of row weights. Used only is CA is NULL.