Predicts response based on CDA (correspondence discriminant analysis) submodels generated by cross validation. The predicted class is given with its probability (computed from the values predicted by all submodels).
# S3 method for CDA.cv
predict(object, newdata, method = c("mahalanobis", "euclidian"), ...)object of class inheriting from "CDA.cv".
vector, matrix or data frame giving new individuals (one row per individual).
criterion used to predict class membership. See predict.coadisc.
further arguments to be passed to or from other methods.