Usage
scatter.coa2(x, xax = 1, yax = 2, sep = TRUE, boxes = FALSE,
method = 1:3, clab.row = 0.75, clab.col = 1.25, posieig = "none",
sub = NULL, csub = 2, ...)
Arguments
xax
the column number for the x-axis (horizontal).
yax
the column number for the y-axis (vertical).
sep
a logical value indicating if score plots of rows and columns should be plotted separately (default) or not. If TRUE, the sale scale is applied to both plots.
boxes
a logical value indicating whether a box should be drawn around labels.
method
an integer between 1 and 3. 1: rows and columns with the coordinates of lambda variance. 2: rows variance 1 and columns by averaging. 3: columns variance 1 and rows by averaging.
clab.row
a character size for the rows.
clab.col
a character size for the columns. If sep is TRUE, size given by clab.row is applied in both plots.
posieig
if "top" the eigenvalues bar plot is upside, if "bottom" it is downside, if "none" no plot.
sub
a string of characters to be inserted as legend.
csub
a character size for the legend, used with par("cex")*csub.
...
further arguments passed to or from other methods.