G.test(x, p = rep(1/length(x), length(x)))x is matrix, it must be constructed like this:
- 2 columns giving number of successes (left) and fails (right)
- 1 row per population.
The function works as chisq.test() :
- if x is a vector and theoretical proportions are not given, equality of counts is tested
- if x is a vector and theoretical proportions are given, equality of counts to theoretical counts (given by theoretical proportions) is tested
- if x is a matrix, equality of proportion of successes between populations is tested.chisq.test, G.multcomp, G.theo.multcomp, pairwise.G.test