Usage
multtest.gp(tab, fac, test = c("param", "perm", "rank"),
transform = c("none", "sqrt", "log"), add = 0, p.method = "fdr",
ordered = TRUE, ...)
## S3 method for class 'multtest.gp':
plot(x, signif = FALSE, alpha = 0.05,
xlab = "Group", ylab = "Mean (+/- SE) value", titles = NULL,
groups = NULL, ...)Arguments
tab
data frame containing response variables.
fac
factor defining groups to compare.
test
type of test to use: parametric (default), permutational (non parametric) or rank-based (non parametric). See Details.
transform
transformation to apply to response variables before testing (none by default). Only used for parametric and permutational tests.
add
value to add to response variables before a log-transformation.
p.method
method for p-values correction. See help of p.adjust. ordered
logical indicating if variables should be ordered based on p-values.
x
object returned from multtest.gp.
signif
logical indicating if only variables with significant P-value should be plotted.
alpha
significance threshold.
xlab
legend of the x axis.
titles
titles of the graphs (name of the variables by default).
groups
names of the bars (levels of fac by default).
...
additional arguments to testing functions in multtest.gp (especially for var.equal in t.test and nperm in perm.ano